<?php

/**
 * @file
 * Entity Workflow API documentation.
 */

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Allows altering the configuration of entity workflow plugins.
 *
 * @param array $configuration
 *   The configuration of the entity workflow plugin.
 * @param string $plugin_id
 *   The entity workflow plugin ID.
 */
function hook_entity_workflow_type_alter(array &$configuration, $plugin_id) {
  if ($plugin_id === 'entity_workflow_test_content') {
    $configuration['default_transition_log'] = t('The entity has been edited in a workspace.');
  }
}

/**
 * Allows altering the workflow state label.
 *
 * @param string $label
 *   The current state label.
 * @param array $context
 *   An array of context data containing 'entity', 'state', and 'workspace'.
 *   Note that 'entity' and 'workspace' are optional contexts, and they might
 *   not be always populated, for example, when visiting the workflow edit UI.
 */
function hook_entity_workflow_state_label_alter(&$label, array $context) {
  if ($context['entity']->getEntityTypeId() === 'custom_entity') {
    $label = t('Custom label');
  }
}

/**
 * Allows giving access to the entity workflow tab.
 *
 * @param bool $access
 *   Whether or not to provide access. Will be FALSE by default unless changed
 *   by an alter.
 * @param \Drupal\workflows\WorkflowInterface $workflow
 *   The workflow configuration entity.
 * @param \Drupal\Core\Entity\EntityInterface $entity
 *   The entity.
 */
function hook_entity_workflow_has_bulk_workflow_alter(&$access, \Drupal\workflows\WorkflowInterface $workflow, \Drupal\Core\Entity\EntityInterface $entity) {
  $access = TRUE;
}

/**
 * Returns a list of entities that should be presented on the bulk workflow tab.
 *
 * @param \Drupal\workflows\WorkflowInterface $workflow
 *   The workflow configuration entity.
 * @param \Drupal\Core\Entity\EntityInterface $entity
 *   The entity.
 *
 * @return array
 *   An array of entities. The key for each entity MUST be $entity_type . '--' .
 *   $entity_id.
 */
function hook_entity_workflow_bulk_workflow_entities(\Drupal\workflows\WorkflowInterface $workflow, \Drupal\Core\Entity\EntityInterface $entity) {
  return [];
}

/**
 * @} End of "addtogroup hooks".
 */
