<?php

namespace Drupal\entity_workflow\FieldType;

use Drupal\Core\Entity\FieldableEntityInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\workflows\WorkflowStateFieldItemList;

/**
 * Defines a custom item list class for the 'workflow_state' field type.
 */
class EntityWorkflowStateFieldItemList extends WorkflowStateFieldItemList {

  /**
   * {@inheritdoc}
   */
  public static function processDefaultValue($default_value, FieldableEntityInterface $entity, FieldDefinitionInterface $definition) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function preSave() {
    /** @var \Drupal\Core\Entity\RevisionableInterface $entity */
    $entity = $this->getEntity();

    // Ensure that workflow states are removed when saving an entity in the
    // default (live) workspace.
    if ($entity->isDefaultRevision() && $entity->getEntityTypeId() !== 'workspace' && !$this->isEmpty()) {
      $this->list[0]->set('value',  NULL);
      return;
    }

    // Skip applying any default transition if this entity is saved in the
    // default (Live) workspace.
    if (!\Drupal::service('workspaces.manager')->hasActiveWorkspace()) {
      return;
    }

    // Skip workflow fields that already have a state set.
    if (!$this->isEmpty()) {
      return;
    }

    /** @var \Drupal\entity_workflow\FieldType\EntityWorkflowStateItem $item */
    $item = $this->appendItem();
    /** @var \Drupal\entity_workflow\WorkflowType\EntityWorkflowTypeInterface $workflow */
    $workflow = $item->getWorkflow()->getTypePlugin();

    // If there is no default transition to write, or the current state on the
    // field is not the default state.
    if (!$workflow->getDefaultTransition() || ($item->value && ($workflow->getDefaultState() != $item->value))) {
      return;
    }

    // When adding an entity to a workspace, we may have a default transition
    // requested. If so, record it so that the history is maintained.
    $transition = $workflow->getTransition($workflow->getDefaultTransition());
    $log = $workflow->getDefaultTransitionLog();
    $item->applyTransition($transition, $log);

    parent::preSave();
  }

}
