<?php

namespace Drupal\entity_workflow\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\entity_workflow\EntityWorkflowInfo;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides local action definitions for entity workflows.
 */
class EntityWorkflowLocalActions extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The entity workflow information service.
   *
   * @var \Drupal\entity_workflow\EntityWorkflowInfo
   */
  protected $entityWorkflowInfo;

  /**
   * Creates a EntityWorkflowLocalTasks object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\entity_workflow\EntityWorkflowInfo $entity_workflow_info
   *   The entity workflow information service.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The translation manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, EntityWorkflowInfo $entity_workflow_info, TranslationInterface $string_translation) {
    $this->entityTypeManager = $entity_type_manager;
    $this->entityWorkflowInfo = $entity_workflow_info;
    $this->stringTranslation = $string_translation;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('entity_workflow.info'),
      $container->get('string_translation')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $this->derivatives = [];

    foreach ($this->entityTypeManager->getDefinitions() as $entity_type_id => $entity_type) {
      foreach ($this->entityWorkflowInfo->getWorkflowPluginsForEntityType($entity_type_id) as $workflow_id => $workflow_type) {
        foreach ($workflow_type->getTransitions() as $transition_id => $transition) {
          /** @var \Drupal\entity_workflow\EntityWorkflowTransition $transition */
          if ($transition->hasActionLink()) {
            $this->derivatives["$entity_type_id.{$workflow_id}_workflow_{$transition_id}_transition"] = [
              'route_name' => "entity.$entity_type_id.workflow_transition",
              'route_parameters' => [
                'workflow' => $workflow_id,
                'transition_id' => $transition_id
              ],
              'weight' => 50,
              'title' => $transition->label(),
              'appears_on' => ["entity.$entity_type_id.canonical"],
            ] + $base_plugin_definition;
          }
        }
      }
    }

    return $this->derivatives;
  }

}
