<?php

namespace Drupal\entity_workflow;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\workflows\WorkflowInterface;
use Drupal\workspaces\WorkspaceInterface;

/**
 * Validates whether a certain state transition is allowed.
 */
interface StateTransitionValidatorInterface {

  /**
   * Gets a list of transitions that are legal for this user on this entity.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity to be transitioned.
   * @param \Drupal\workflows\WorkflowInterface $workflow
   *   The workflow entity.
   * @param \Drupal\Core\Session\AccountInterface $user
   *   The account that wants to perform a transition.
   *
   * @return \Drupal\entity_workflow\EntityWorkflowTransition[]
   *   The list of transitions that are legal for this user on this entity.
   */
  public function getValidTransitions(ContentEntityInterface $entity, WorkflowInterface $workflow, AccountInterface $user, WorkspaceInterface $workspace = NULL);

  /**
   * Checks if a transition between two states if valid for the given user.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity to be transitioned.
   * @param \Drupal\workflows\WorkflowInterface $workflow
   *   The workflow entity.
   * @param string $transition_id
   *   The ID of the transition to be performed.
   * @param \Drupal\Core\Session\AccountInterface $user
   *   The user to validate.
   * @param \Drupal\workspaces\WorkspaceInterface|null $workspace
   *   The workspace entity.
   *
   * @return bool
   *   Returns TRUE if transition is valid, FALSE otherwise.
   */
  public function isTransitionValid(ContentEntityInterface $entity, WorkflowInterface $workflow, $transition_id, AccountInterface $user, WorkspaceInterface $workspace = NULL);

}
