<?php

namespace Drupal\entity_workflow;

use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Provides an interface defining a workflow transition log entity.
 */
interface WorkflowTransitionLogInterface extends ContentEntityInterface {

  /**
   * Gets the workflow ID.
   *
   * @return string
   *   The ID of the workflow entity.
   */
  public function getWorkflowId();

  /**
   * Gets the workflow.
   *
   * @return \Drupal\workflows\WorkflowInterface
   *   The workflow entity.
   */
  public function getWorkflow();

  /**
   * Gets the source entity ID.
   *
   * @return mixed
   *   The entity ID.
   */
  public function getSourceEntityId();

  /**
   * Gets the source entity type ID.
   *
   * @return string
   *   The entity type ID.
   */
  public function getSourceEntityTypeId();

  /**
   * Gets the source entity.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface
   *   The source entity.
   */
  public function getSourceEntity();

  /**
   * Gets the user ID.
   *
   * @return int
   *   The user ID.
   */
  public function getUserId();

  /**
   * Gets the user.
   *
   * @return \Drupal\user\UserInterface
   *   The user entity.
   */
  public function getUser();

  /**
   * Gets the log creation timestamp.
   *
   * @return int
   *   Creation timestamp of the log.
   */
  public function getCreatedTime();

  /**
   * Sets the log creation timestamp.
   *
   * @param int $timestamp
   *   The log creation timestamp.
   *
   * @return $this
   */
  public function setCreatedTime($timestamp);

}
