<?php

namespace Drupal\entity_workflow;

use Drupal\Core\Entity\ContentEntityTypeInterface;
use Drupal\Core\Entity\Sql\SqlContentEntityStorageSchema;
use Drupal\Core\Field\FieldStorageDefinitionInterface;

/**
 * Defines the workflow_transition_log schema handler.
 */
class WorkflowTransitionLogStorageSchema extends SqlContentEntityStorageSchema {

  /**
   * {@inheritdoc}
   */
  protected function getEntitySchema(ContentEntityTypeInterface $entity_type, $reset = FALSE) {
    $schema = parent::getEntitySchema($entity_type, $reset);

    if ($base_table = $this->storage->getBaseTable()) {
      $schema[$base_table]['indexes'] += [
        'transition_log__entity_id' => ['entity_type_id', 'entity_id'],
        'transition_log__entity_string_id' => ['entity_type_id', 'entity_id_string'],
      ];

      if (isset($schema[$base_table]['fields']['workspace_id'])) {
        $schema[$base_table]['indexes'] += [
          'transition_log__workspace_id' => ['entity_type_id', 'workspace_id'],
        ];
      }
    }

    return $schema;
  }

  /**
   * {@inheritdoc}
   */
  protected function getSharedTableFieldSchema(FieldStorageDefinitionInterface $storage_definition, $table_name, array $column_mapping) {
    $schema = parent::getSharedTableFieldSchema($storage_definition, $table_name, $column_mapping);
    $field_name = $storage_definition->getName();

    if ($table_name == $this->storage->getBaseTable()) {
      // Remove unneeded indexes.
      unset($schema['indexes'][$this->getFieldSchemaIdentifierName('workflow_transition_log', 'uid', 'target_id')]);
      unset($schema['indexes'][$this->getFieldSchemaIdentifierName('workflow_transition_log', 'workspace_id', 'target_id')]);

      // Improve performance of some fields.
      switch ($field_name) {
        case 'entity_type_id':
        case 'uid':
        case 'created':
          $schema['fields'][$field_name]['not null'] = TRUE;
          break;
      }
    }

    return $schema;
  }

}
