<?php

namespace Drupal\entity_workflow\WorkflowType;

/**
 * Provides convenience methods for workflow types that are not configurable.
 */
trait NonConfigurableWorkflowTypeTrait {

  /**
   * {@inheritdoc}
   */
  public function addState($state_id, $label) {
    // Entity workflows are not configurable from the UI.
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setStateLabel($state_id, $label) {
    // Entity workflows are not configurable from the UI.
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setStateWeight($state_id, $weight) {
    // Entity workflows are not configurable from the UI.
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function deleteState($state_id) {
    // Entity workflows are not configurable from the UI.
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function addTransition($transition_id, $label, array $from_state_ids, $to_state_id) {
    // Entity workflows are not configurable from the UI.
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setTransitionLabel($transition_id, $label) {
    // Entity workflows are not configurable from the UI.
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setTransitionWeight($transition_id, $weight) {
    // Entity workflows are not configurable from the UI.
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setTransitionFromStates($transition_id, array $from_state_ids) {
    // Entity workflows are not configurable from the UI.
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function deleteTransition($transition_id) {
    // Entity workflows are not configurable from the UI.
    return $this;
  }

}
