<?php

namespace Drupal\entity_workflow_test\Plugin\WorkflowType;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\entity_workflow\WorkflowType\EntityWorkflowTypeBase;

/**
 * @WorkflowType(
 *   id = "entity_workflow_test_content",
 *   label = @Translation("Entity workflow test (Content)"),
 * )
 */
class EntityWorkflowTestContent extends EntityWorkflowTypeBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    $supported_entity_types = array_filter($this->entityTypeManager->getDefinitions(), function (EntityTypeInterface $entity_type) {
      return $this->workspaceManager->isEntityTypeSupported($entity_type);
    });
    return [
      'entity_types' => array_fill_keys(array_keys($supported_entity_types), []),
      'default_state' => 'draft',
      'default_transition' => 'new',
      'default_transition_log' => t('The entity has been edited in a workspace.'),
      'states' => [
        'draft' => [
          'label' => t('Draft'),
          'weight' => 1,
        ],
        'review' => [
          'label' => t('Ready for Review'),
          'weight' => 10,
        ],
        'approved' => [
          'label' => t('Approved'),
          'weight' => 20,
        ],
      ],
      'transitions' => [
        'new' => [
          'label' => t('New'),
          'from' => [],
          'to' => 'draft',
          'weight' => 0,
        ],
        'ready_for_review' => [
          'label' => t('Ready for Review'),
          'from' => ['draft'],
          'to' => 'review',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 10,
        ],
        'approve' => [
          'label' => t('Approve'),
          'from' => ['review'],
          'to' => 'approved',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 20,
        ],
        'approve_immediately' => [
          'label' => t('Approve immediately'),
          'from' => ['draft'],
          'to' => 'approved',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 30,
        ],
        'back_to_draft' => [
          'label' => t('Back to Draft'),
          'from' => ['review', 'approved'],
          'to' => 'draft',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 40,
        ],
      ],
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function getPermissions() {
    $perms = [];
    foreach ($this->configuration['transitions'] as $transition_id => $transition_info) {
      $perms["use content transition $transition_id"] = [
        'title' => $this->t('Use the %label content transition.', ['%label' => $transition_info['label']]),
      ];
    }

    return $perms;
  }

}
