<?php

namespace Drupal\entity_workflow_test\Plugin\WorkflowType;

use Drupal\entity_workflow\WorkflowType\EntityWorkflowTypeBase;

/**
 * @WorkflowType(
 *   id = "entity_workflow_test_workspace",
 *   label = @Translation("Entity workflow test (Workspace)"),
 * )
 */
class EntityWorkflowTestWorkspace extends EntityWorkflowTypeBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'entity_types' => [
        'workspace' => [],
      ],
      'default_state' => 'draft',
      'default_transition' => 'new',
      'default_transition_log' => t('Workspace has been created.'),
      'states' => [
        'draft' => [
          'label' => t('Draft'),
          'weight' => 1,
        ],
        'review' => [
          'label' => t('Review'),
          'weight' => 10,
        ],
        'published' => [
          'label' => t('Published'),
          'weight' => 20,
        ],
      ],
      'transitions' => [
        'new' => [
          'label' => t('New'),
          'from' => [],
          'to' => 'draft',
          'weight' => 0,
        ],
        'submit_for_review' => [
          'label' => t('Submit for Review'),
          'from' => ['draft'],
          'to' => 'review',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 10,
        ],
        'back_to_draft' => [
          'label' => t('Back to Draft'),
          'from' => ['review'],
          'to' => 'draft',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 20,
        ],
        'publish' => [
          'label' => t('Publish'),
          'from' => ['review'],
          'to' => 'published',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 30,
        ],
        'unpublish' => [
          'label' => t('Unpublish'),
          'from' => ['published'],
          'to' => 'review',
          'transition_log' => TRUE,
          'action_link' => TRUE,
          'weight' => 40,
        ],
      ],
    ] + parent::defaultConfiguration();
  }

}
